@@ -30,7 +30,7 @@ import secrets
 from botocore.session import Session
 from botocore.credentials import ReadOnlyCredentials
 
-__version__ = '0.12.0'
+__version__ = '0.13.0'
 
 LOGGER = logging.getLogger('aws-export-credentials')
 
@@ -454,7 +454,14 @@ class IMDSRequestHandler(BaseHTTPRequestHandler):
         if not self._role_name:
             response = self._sts_client.get_caller_identity()
             arn = response["Arn"]
-            self._role_name = arn.rsplit("/", 1)[1]
+            arn_parts = arn.split(":")
+            name_parts = arn_parts[-1].split("/")
+            name_type = name_parts[0]
+            if name_type == "user":
+                role_name = name_parts[-1]
+            else:
+                role_name = name_parts[1]
+            self._role_name = role_name
 
     def do_GET(self):
         if self.path == "/latest/api/token":
@@ -494,7 +501,7 @@ class IMDSRequestHandler(BaseHTTPRequestHandler):
                     body['Expiration'] = serialize_date(credentials.Expiration)
                 else:
                     # An expiration is required
-                    body['Expiration'] = datetime.now(tz=timezone.utc) + timedelta(minutes=60)
+                    body['Expiration'] = serialize_date(datetime.now(tz=timezone.utc) + timedelta(minutes=60))
                 return self.send_ok("application/json", body)
         return self.send_error(
             HTTPStatus.NOT_FOUND,
